==> jc-1.4.0.tar.gz: gnu/xml/dom/DomNode__24ShadowList.h <==
// final class gnu.xml.dom.DomNode$ShadowList

// class file dependencies
// @dep_class 7c7d9976a7432a6e gnu_xml_dom_DomNode__24ShadowList
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_dom_DomNode__24ShadowList_H_
#define _JC_gnu_xml_dom_DomNode__24ShadowList_H_

// Forward structure declarations
struct _jc_gnu_xml_dom_DomNode$object;
struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomNode__24ShadowList$sub_refs	_jc_gnu_xml_dom_DomNode__24ShadowList$sub_refs;
typedef struct _jc_gnu_xml_dom_DomNode__24ShadowList$sub_nonrefs	_jc_gnu_xml_dom_DomNode__24ShadowList$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomNode__24ShadowList$refs	_jc_gnu_xml_dom_DomNode__24ShadowList$refs;
typedef struct _jc_gnu_xml_dom_DomNode__24ShadowList$nonrefs	_jc_gnu_xml_dom_DomNode__24ShadowList$nonrefs;
typedef struct _jc_gnu_xml_dom_DomNode__24ShadowList$object	_jc_gnu_xml_dom_DomNode__24ShadowList$object;

typedef const struct _jc_gnu_xml_dom_DomNode__24ShadowList$vmethods	_jc_gnu_xml_dom_DomNode__24ShadowList$vmethods;
typedef const struct _jc_gnu_xml_dom_DomNode__24ShadowList$vtable	_jc_gnu_xml_dom_DomNode__24ShadowList$vtable;
typedef const struct _jc_gnu_xml_dom_DomNode__24ShadowList$vtype	_jc_gnu_xml_dom_DomNode__24ShadowList$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomNode__24ShadowList$method$_init$8f7e550af1d1e699(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24ShadowList$object *, struct _jc_gnu_xml_dom_DomNode$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_gnu_xml_dom_DomNode__24ShadowList$method$finalize$660a5b5b608ff21f(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24ShadowList$object *);
extern jint _jc_gnu_xml_dom_DomNode__24ShadowList$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24ShadowList$object *);
extern struct _jc_object *_jc_gnu_xml_dom_DomNode__24ShadowList$method$item$768348a8778b0a3e(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24ShadowList$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomNode__24ShadowList$method_info$finalize$660a5b5b608ff21f;
extern _jc_method _jc_gnu_xml_dom_DomNode__24ShadowList$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_gnu_xml_dom_DomNode__24ShadowList$method_info$item$768348a8778b0a3e;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomNode__24ShadowList$vmethods {
	void	(*finalize$660a5b5b608ff21f)(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24ShadowList$object *);
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24ShadowList$object *);
	struct _jc_object	*(*item$768348a8778b0a3e)(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24ShadowList$object *, jint);
};

// Vtable
struct _jc_gnu_xml_dom_DomNode__24ShadowList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomNode__24ShadowList$vmethods	gnu_xml_dom_DomNode__24ShadowList;
};

// Vtype
struct _jc_gnu_xml_dom_DomNode__24ShadowList$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomNode__24ShadowList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomNode__24ShadowList$sub_refs {
	struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object	*liveList;
	struct _jc_gnu_xml_dom_DomNode$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomNode__24ShadowList$refs {
    _jc_gnu_xml_dom_DomNode__24ShadowList$sub_refs	gnu_xml_dom_DomNode__24ShadowList;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomNode__24ShadowList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomNode__24ShadowList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomNode__24ShadowList$sub_nonrefs	gnu_xml_dom_DomNode__24ShadowList;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomNode__24ShadowList$object {
	_jc_gnu_xml_dom_DomNode__24ShadowList$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomNode__24ShadowList$vtype	*vtype;
	_jc_gnu_xml_dom_DomNode__24ShadowList$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomNode__24ShadowList$vtype _jc_gnu_xml_dom_DomNode__24ShadowList$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomNode__24ShadowList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomNode__24ShadowList$class_object;

#endif	/* _JC_gnu_xml_dom_DomNode__24ShadowList_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/dom/DomNode__24ShadowList.h <==
// final class gnu.xml.dom.DomNode$ShadowList

// class file dependencies
// @dep_class 7c7d9976a7432a6e gnu_xml_dom_DomNode__24ShadowList
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_dom_DomNode__24ShadowList_H_
#define _JC_gnu_xml_dom_DomNode__24ShadowList_H_

// Forward structure declarations
struct _jc_gnu_xml_dom_DomNode$object;
struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomNode__24ShadowList$sub_refs	_jc_gnu_xml_dom_DomNode__24ShadowList$sub_refs;
typedef struct _jc_gnu_xml_dom_DomNode__24ShadowList$sub_nonrefs	_jc_gnu_xml_dom_DomNode__24ShadowList$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomNode__24ShadowList$refs	_jc_gnu_xml_dom_DomNode__24ShadowList$refs;
typedef struct _jc_gnu_xml_dom_DomNode__24ShadowList$nonrefs	_jc_gnu_xml_dom_DomNode__24ShadowList$nonrefs;
typedef struct _jc_gnu_xml_dom_DomNode__24ShadowList$object	_jc_gnu_xml_dom_DomNode__24ShadowList$object;

typedef const struct _jc_gnu_xml_dom_DomNode__24ShadowList$vmethods	_jc_gnu_xml_dom_DomNode__24ShadowList$vmethods;
typedef const struct _jc_gnu_xml_dom_DomNode__24ShadowList$vtable	_jc_gnu_xml_dom_DomNode__24ShadowList$vtable;
typedef const struct _jc_gnu_xml_dom_DomNode__24ShadowList$vtype	_jc_gnu_xml_dom_DomNode__24ShadowList$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomNode__24ShadowList$method$_init$8f7e550af1d1e699(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24ShadowList$object *, struct _jc_gnu_xml_dom_DomNode$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_xml_dom_DomNode__24ShadowList$method$finalize$660a5b5b608ff21f(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24ShadowList$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_xml_dom_DomNode__24ShadowList$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24ShadowList$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_dom_DomNode__24ShadowList$method$item$768348a8778b0a3e(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24ShadowList$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomNode__24ShadowList$method_info$finalize$660a5b5b608ff21f;
extern _jc_method _jc_gnu_xml_dom_DomNode__24ShadowList$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_gnu_xml_dom_DomNode__24ShadowList$method_info$item$768348a8778b0a3e;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomNode__24ShadowList$vmethods {
	void	(*finalize$660a5b5b608ff21f)(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24ShadowList$object *) _JC_JCNI_ATTR;
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24ShadowList$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*item$768348a8778b0a3e)(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24ShadowList$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_dom_DomNode__24ShadowList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomNode__24ShadowList$vmethods	gnu_xml_dom_DomNode__24ShadowList;
};

// Vtype
struct _jc_gnu_xml_dom_DomNode__24ShadowList$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomNode__24ShadowList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomNode__24ShadowList$sub_refs {
	struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object	*liveList;
	struct _jc_gnu_xml_dom_DomNode$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomNode__24ShadowList$refs {
    _jc_gnu_xml_dom_DomNode__24ShadowList$sub_refs	gnu_xml_dom_DomNode__24ShadowList;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomNode__24ShadowList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomNode__24ShadowList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomNode__24ShadowList$sub_nonrefs	gnu_xml_dom_DomNode__24ShadowList;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomNode__24ShadowList$object {
	_jc_gnu_xml_dom_DomNode__24ShadowList$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomNode__24ShadowList$vtype	*vtype;
	_jc_gnu_xml_dom_DomNode__24ShadowList$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomNode__24ShadowList$vtype _jc_gnu_xml_dom_DomNode__24ShadowList$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomNode__24ShadowList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomNode__24ShadowList$class_object;

#endif	/* _JC_gnu_xml_dom_DomNode__24ShadowList_H_ */
